@@ -114,46 +114,67 @@ def test_client_statsd(
     worker_fn = MagicMock()
     client.process(worker_fn)
 
+    group_tag = f"#group:{kafka_consumer_group}"
+
     worker_fn.assert_called_once_with({"revision": [REV]})
     assert client.statsd.namespace == "swh_journal_client"
     # check at least initialization of the status gauge is ok
-    assert client.statsd.socket.recv() == "swh_journal_client.status:0|g|#status:idle"
     assert (
         client.statsd.socket.recv()
-        == "swh_journal_client.status:0|g|#status:processing"
+        == f"swh_journal_client.status:0|g|{group_tag},status:idle"
     )
     assert (
-        client.statsd.socket.recv() == "swh_journal_client.status:0|g|#status:waiting"
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:0|g|{group_tag},status:processing"
+    )
+    assert (
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:0|g|{group_tag},status:waiting"
     )
     # processing the batch with only one message
-    assert client.statsd.socket.recv() == "swh_journal_client.status:1|g|#status:idle"
-    assert client.statsd.socket.recv() == "swh_journal_client.status:0|g|#status:idle"
     assert (
-        client.statsd.socket.recv() == "swh_journal_client.status:1|g|#status:waiting"
-    )
-    assert (
-        client.statsd.socket.recv() == "swh_journal_client.status:0|g|#status:waiting"
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:1|g|{group_tag},status:idle"
     )
     assert (
         client.statsd.socket.recv()
-        == "swh_journal_client.status:1|g|#status:processing"
+        == f"swh_journal_client.status:0|g|{group_tag},status:idle"
     )
     assert (
         client.statsd.socket.recv()
-        == "swh_journal_client.status:0|g|#status:processing"
+        == f"swh_journal_client.status:1|g|{group_tag},status:waiting"
+    )
+    assert (
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:0|g|{group_tag},status:waiting"
+    )
+    assert (
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:1|g|{group_tag},status:processing"
+    )
+    assert (
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:0|g|{group_tag},status:processing"
+    )
+    assert (
+        client.statsd.socket.recv()
+        == f"swh_journal_client.status:1|g|{group_tag},status:idle"
     )
-    assert client.statsd.socket.recv() == "swh_journal_client.status:1|g|#status:idle"
     # from there, status messages can be mixed with a few other ones...
     assert (
-        b"swh_journal_client.handle_message_total:1|c" in client.statsd.socket.payloads
+        f"swh_journal_client.handle_message_total:1|c|{group_tag}".encode()
+        in client.statsd.socket.payloads
+    )
+    assert (
+        f"swh_journal_client.stop_total:1|c|{group_tag}".encode()
+        in client.statsd.socket.payloads
     )
-    assert b"swh_journal_client.stop_total:1|c" in client.statsd.socket.payloads
     # and some waiting/idle forth and back may have happened, so only check the
     # last 3 messages resetting the status gauges)
     assert list(client.statsd.socket.payloads)[-3:] == [
-        b"swh_journal_client.status:0|g|#status:idle",
-        b"swh_journal_client.status:0|g|#status:processing",
-        b"swh_journal_client.status:0|g|#status:waiting",
+        f"swh_journal_client.status:0|g|{group_tag},status:idle".encode(),
+        f"swh_journal_client.status:0|g|{group_tag},status:processing".encode(),
+        f"swh_journal_client.status:0|g|{group_tag},status:waiting".encode(),
     ]
 
 
@@ -333,7 +354,7 @@ def test_client_batch_size(
         brokers=[kafka_server],
         group_id=kafka_consumer_group,
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         batch_size=batch_size,
     )
 
@@ -385,7 +406,7 @@ def test_client_subscribe_all(
         brokers=[kafka_server_base],
         group_id="whatever",
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
     )
     assert set(client.subscription) == {
         f"{kafka_prefix}.something",
@@ -409,7 +430,7 @@ def test_client_subscribe_one_topic(
         brokers=[kafka_server_base],
         group_id="whatever",
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         object_types=["else"],
     )
     assert client.subscription == [f"{kafka_prefix}.else"]
@@ -427,7 +448,7 @@ def test_client_subscribe_absent_topic(
             brokers=[kafka_server_base],
             group_id="whatever",
             prefix=kafka_prefix,
-            stop_on_eof=True,
+            on_eof=EofBehavior.STOP,
             object_types=["really"],
         )
 
@@ -440,14 +461,14 @@ def test_client_subscribe_absent_prefix(
             brokers=[kafka_server_base],
             group_id="whatever",
             prefix="wrong.prefix",
-            stop_on_eof=True,
+            on_eof=EofBehavior.STOP,
         )
     with pytest.raises(ValueError):
         JournalClient(
             brokers=[kafka_server_base],
             group_id="whatever",
             prefix="wrong.prefix",
-            stop_on_eof=True,
+            on_eof=EofBehavior.STOP,
             object_types=["else"],
         )
 
@@ -482,7 +503,7 @@ def test_client_subscriptions_with_anonymized_topics(
         brokers=[kafka_server_base],
         group_id=kafka_consumer_group,
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         privileged=False,
     )
     # we only subscribed to "standard" topics
@@ -523,7 +544,7 @@ def test_client_subscriptions_without_anonymized_topics(
         brokers=[kafka_server_base],
         group_id=kafka_consumer_group,
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         privileged=False,
     )
     # we only subscribed to the standard prefix
@@ -534,7 +555,7 @@ def test_client_subscriptions_without_anonymized_topics(
         brokers=[kafka_server_base],
         group_id=kafka_consumer_group,
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         privileged=True,
     )
     # we also only subscribed to the standard prefix, since there is no priviled prefix
@@ -575,7 +596,7 @@ def test_client_with_deserializer(
         brokers=[kafka_server],
         group_id=kafka_consumer_group,
         prefix=kafka_prefix,
-        stop_on_eof=True,
+        on_eof=EofBehavior.STOP,
         value_deserializer=custom_deserializer,
     )
     worker_fn = MagicMock()
@@ -589,3 +610,29 @@ def test_client_with_deserializer(
     processed_revisions = set(worker_fn.call_args[0][0]["revision"])
     assert revisions[0] not in processed_revisions
     assert all(rev in processed_revisions for rev in revisions[1:])
+
+
+def test_client_create_topics(
+    kafka_prefix: str, kafka_consumer_group: str, kafka_server_base: str, mocker
+):
+
+    # the Mock broker does not support the CreateTopic admin API, so we
+    # mock the call to AdminClient.create_topics
+    mock_admin = mocker.patch("swh.journal.client.AdminClient")
+    mock_topic_future = mocker.Mock()
+    mock_topic_future.result.return_value = None
+    mock_admin.create_topics.return_value = {
+        kafka_prefix + ".revision": mock_topic_future
+    }
+
+    client = JournalClient(
+        brokers=[kafka_server_base],
+        group_id=kafka_consumer_group,
+        prefix=kafka_prefix,
+        on_eof=EofBehavior.STOP,
+        privileged=False,
+        object_types=["revision"],
+        create_topics=True,
+    )
+
+    assert client.subscription == [kafka_prefix + ".revision"]
